import org.jetbrains.kotlin.gradle.dsl.JvmTarget

plugins {
    `kotlin-dsl`
}

group = "com.test.buildlogic"

// Configure the build-logic plugins to target JDK 17
// This matches the JDK used to build the project, and is not related to what is running on device.
java {
	sourceCompatibility = JavaVersion.VERSION_17
	targetCompatibility = JavaVersion.VERSION_17
}

kotlin {
	compilerOptions {
		jvmTarget = JvmTarget.JVM_17
	}
}


repositories {
    google()
    mavenCentral()
    gradlePluginPortal()
}

dependencies {
	compileOnly(libs.android.gradlePlugin)
	compileOnly(libs.android.tools.common)
	compileOnly(libs.compose.gradlePlugin)
	compileOnly(libs.firebase.crashlytics.gradlePlugin)
	compileOnly(libs.firebase.performance.gradlePlugin)
	compileOnly(libs.kotlin.gradlePlugin)
	compileOnly(libs.ksp.gradlePlugin)
}

tasks {
	validatePlugins {
		enableStricterValidation = true
		failOnWarning = true
	}
}

gradlePlugin {
	plugins {
		register("androidApplication") {
			id = "market.android.application"
			implementationClass = "AndroidApplicationConventionPlugin"
		}
		register("androidLibrary") {
			id = "market.android.library"
			implementationClass = "AndroidLibraryConventionPlugin"
		}

		register("androidCompose") {
			id = "market.android.compose"
			implementationClass = "AndroidComposeConventionPlugin"
		}
		register("androidHilt") {
			id = "market.android.hilt"
			implementationClass = "AndroidHiltConventionPlugin"
		}


	}
}

